WSx - Heros Devices 0.10.3 documentation

Skip to content
Back to top
View this page

# WSx

From: HighFinesse GmbH

Class: `herosdevices.hardware.highfinesse.wsx.WSx`

Driver Quality Index: beta

A Highfinesse WSx series wavelength meter.

Tested with WS6 and WS7.

Hardware driver to communicate with a High Finesse WSx Wavemeter via the DLL in present in Windows systems with the vendor software installed.

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.highfinesse.wsx.WSx` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
dll_path | <class ‘str’> | C:WindowsSystem32wlmData.dll |
wavemeter_index | <class ‘int’> | 0 |
channels | <class ‘tuple’> | (0, 1, 2, 3, 4, 5, 6, 7) |

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `WSx` using BOSS.

    {
        "_id": "my_WSx",
        "classname": "herosdevices.hardware.highfinesse.wsx.WSx",
        "arguments": {
            "dll_path": "C:\\Windows\\System32\\wlmData.dll",
            "wavemeter_index": 0,
            "channels": [
                0,
                1,
                2,
                3,
                4,
                5,
                6,
                7
            ]
        }
    }

generated from signature

Inheritance